@@ -8,15 +8,15 @@ dir = os.getcwd()
 sys.path.append(dir + "\SmartApi")
 #print(sys.path)
 
-from smartapi.smartConnect import SmartConnect
+from smartConnect import SmartConnect
 
-smartApi =SmartConnect()
+smartApi =SmartConnect(api_key="smartapi_key")
 
-login = smartApi.generateSession('D88311', 'Angel@444')
+login = smartApi.generateSession('Your client id', 'Password')
 print(login)
 refreshToken = login['data']['refreshToken']
 smartApi.getProfile(refreshToken)
-smartApi.generateToken(refreshToken)
+#smartApi.generateToken(refreshToken)
 orderparams = {
     "variety": "NORMAL",
     "tradingsymbol": "SBIN-EQ",
@@ -70,11 +70,11 @@ params={
 }
 
 smartApi.convertPosition(params)
-smartApi.terminateSession('D88311')
+smartApi.terminateSession('Your client code')
 
 from smartapi.smartSocket import SmartSocket
-FEED_TOKEN='1731759952'
-CLIENT_CODE='S212741'
+FEED_TOKEN='feedToken' #'1731759952'
+CLIENT_CODE='Your client id' #'S212741'
 token=None
 ss = SmartSocket(FEED_TOKEN, CLIENT_CODE)
 def on_tick(ws, tick):
